#file plotStocks.py
"""
Gets a stock quote.
Demonstrates an HTTP API.
"""
from matplotlib import pyplot
import csv      # to use the DictReader function for reading a CSV file
import os
import requests
import sys      # to use function exit as well as the argv list

def plot_stock(symbol, format, rows, cols, which):
    # Get data as a CSV file
    url = f"https://www.alphavantage.co/query?apikey={API_KEY}&datatype=csv&function=TIME_SERIES_DAILY&outputsize=compact&symbol={symbol}"
    response = requests.get(url)

    reader = csv.DictReader(response.text.splitlines())

    prices=[]
    dates=[]
    for row in reader:
        prices.append(float(row['close']))
        dates.append(row['timestamp'])
    pyplot.subplot(rows, cols, which)
    pyplot.plot( dates[5:0:-1], prices[5:0:-1], format, label=symbol)
    pyplot.xlabel("Date")
    pyplot.ylabel("Closing Price")
    pyplot.title(symbol, loc='left')
    pyplot.subplots_adjust(hspace=0.5)

# Check for symbol
if len(sys.argv) != 4:
    sys.exit("Usage: python quote.py STOCK-SYMBOL1 STOCK-SYMBOL2 STOCK-SYMBOL3")

symbol1 = sys.argv[1]
symbol2 = sys.argv[2]
symbol3 = sys.argv[3]

# Get API_KEY
API_KEY = os.getenv("API_KEY")
if not API_KEY:
    sys.exit("Missing API_KEY")

plot_stock(symbol1, "r--^", 3, 1, 1)
plot_stock(symbol2, "g--o", 3, 1, 2)
plot_stock(symbol3, "b--v", 3, 1, 3)

pyplot.show()
